@@ -1,7 +1,8 @@
 
 #' @export
 
-r2beta.glm <- function(model, partial=TRUE, method){
+r2beta.glm <- function(model, partial=TRUE, method='sgv',
+                       wtdbin = TRUE, data = NULL){
 
   mod.pql = glmPQL(model)
 
@@ -43,6 +44,8 @@ r2beta.glm <- function(model, partial=TRUE, method){
             } )
   R2 = R2[order(-R2$Rsq),]
 
+  class(R2) <- c('R2', 'data.frame')
+
   return(R2)
 
 }
